#!/bin/sh
#*****************************************************************************
#
#	File:		XtoolsTypeManager.sh
#
#	Purpose:	This is the main ClearCase Type Manager shell script for Xtools
#			applications
#
#	Comments:	Mainly spawns a java process for handling merge situations
#			with Xtools artifacts.
#
#			See mgr_info.sh for supported command line arguments
#
#	Licensed Materials - Property of IBM
#	(C) Copyright IBM Corp. 2002, 2003.  All Rights Reserved.
#
#	US Government Users Restricted Rights - Use, duplication or disclosure
#	restricted by GSA ADP Schedule Contract with IBM Corp.
#
#******************************************************************************

# Get the install dir value
INSTALL_DIR="$(dirname $0)"

# Find OS specific configuration directory
CFG_DIR="$HOME/rational/TeamServerSharedData"
INFO="$OSTYPE $MACHTYPE $HOSTTYPE"
OS_SPECIFIC_CFG_DIR=""
if [ `expr "$INFO" : ".*[Ll][Ii][Nn][Uu][Xx].*"` -gt 0 ]; then
	OS_SPECIFIC_CFG_DIR="$CFG_DIR/linux*"
	if [ `expr "$INFO" : ".*86.*" ` -gt 0 ]; then
		FOLDER_PATH="$CFG_DIR/linux_x86"
		if [ -d $FOLDER_PATH ]; then
			OS_SPECIFIC_CFG_DIR="$FOLDER_PATH"
		fi
	elif [ `expr "$INFO" : ".*64.*" ` -gt 0 ]; then
		FOLDER_PATH="$CFG_DIR/linux_ia64"
		if [ -d $FOLDER_PATH ]; then
			OS_SPECIFIC_CFG_DIR="$FOLDER_PATH"
		fi
	fi
elif [ `expr "$INFO" : ".*[Ss][Oo][Ll][Aa][Rr][Ii][Ss].*"` -gt 0 ]; then
	OS_SPECIFIC_CFG_DIR="$CFG_DIR/sun*"
	FOLDER_PATH="$CFG_DIR/sun5"
	if [ -d $FOLDER_PATH ]; then
		OS_SPECIFIC_CFG_DIR="$FOLDER_PATH"
	fi
elif [ `expr "$INFO" : ".*[Aa][Ii][Xx].*"` -gt 0 ]; then
	OS_SPECIFIC_CFG_DIR="$CFG_DIR/aix*"
	FOLDER_PATH="$CFG_DIR/aix_power"
	if [ -d $FOLDER_PATH ]; then
		OS_SPECIFIC_CFG_DIR="$FOLDER_PATH"
	fi
elif [ `expr "$INFO" : ".*[Hh][Pp].*"` -gt 0 ]; then
	OS_SPECIFIC_CFG_DIR="$CFG_DIR/hp*"
	if [ `expr "$INFO" : ".*64.*" ` -gt 0 ]; then
		FOLDER_PATH="$CFG_DIR/hp11_ia64"
		if [ -d $FOLDER_PATH ]; then
			OS_SPECIFIC_CFG_DIR="$FOLDER_PATH"
		fi
	elif [ `expr "$INFO" : ".*[Pp][Aa].*" ` -gt 0 ]; then
		FOLDER_PATH="$CFG_DIR/hp11_pa"
		if [ -d $FOLDER_PATH ]; then
			OS_SPECIFIC_CFG_DIR="$FOLDER_PATH"
		fi
	fi
fi

# Find Eclipse executable under OS specific configuration directory
ECLIPSE_RUNTIME=""
if [ -n "$OS_SPECIFIC_CFG_DIR" ]; then
	FILE_LIST=`find $OS_SPECIFIC_CFG_DIR -name EclipseAutoLaunchCommand.cfg`
	for CFG_FILE in $FILE_LIST; do
		ECLIPSE_PATH=`cat $CFG_FILE | cut -d\" -f2`
		if [ -f $ECLIPSE_PATH ]; then
			ECLIPSE_RUNTIME="$ECLIPSE_PATH"
			break 1
		fi
	done
fi

# Find Eclipse executable under shared configuration directory
if [ -z "$ECLIPSE_RUNTIME" ]; then
	FILE_LIST=`find $CFG_DIR -name EclipseAutoLaunchCommand.cfg`
	for CFG_FILE in $FILE_LIST; do
		ECLIPSE_PATH=`cat $CFG_FILE | cut -d\" -f2`
		if [ -f $ECLIPSE_PATH ]; then
			ECLIPSE_RUNTIME="$ECLIPSE_PATH"
			break 1
		fi
	done
fi

# Validate eclipse executable path
if [ ! -f $ECLIPSE_RUNTIME ]; then
	echo "ERROR: eclipse executable at \"$ECLIPSE_RUNTIME\" is not exists!"
	exit 1
fi

# Initialize eclipse home directory path
ECLIPSE_DIR="$(dirname $ECLIPSE_RUNTIME)"

# Get the java executable path
# Assume jre is available under eclipse home
JAVA_RUNTIME="$ECLIPSE_DIR/jre/bin/java"

# validate java execute path
if [ ! -f $JAVA_RUNTIME ]; then

	INI_FILE_PATH="$ECLIPSE_DIR/eclipse.ini"
	if [ -f $INI_FILE_PATH ]; then
		old_IFS=$IFS
		IFS=$'\n'
		INI_DATA=`cat $INI_FILE_PATH`
		for FILE_PATH in $INI_DATA; do
			if [ -f $FILE_PATH ]; then
				NAME="$(basename $FILE_PATH)"
				if [ "$NAME" == "javaw" -o "$NAME" == "java" ]; then
					JAVA_RUNTIME="$FILE_PATH"
					break
				fi
			fi
		done
		IFS=$old_IFS
	fi

	if [ ! -f $JAVA_RUNTIME ]; then	
		old_IFS=$IFS
		IFS=':'
		for DIR_PATH in $PATH; do
		    FILE_PATH="$DIR_PATH/java"
		    if [ -f $FILE_PATH ]; then
		    	JAVA_RUNTIME=$FILE_PATH
		    	break
		    fi
		done
		IFS=$old_IFS
	fi
	
	if [ ! -f $JAVA_RUNTIME ]; then
		echo "ERROR: Java executable at \"$JAVA_RUNTIME\" is not exists!"
		exit 1
	fi
fi

JAR_LIST=""

# Create Jar file list
FILE_LIST=`ls $INSTALL_DIR/*.jar`
for FILE_PATH in $FILE_LIST; do
    JAR_LIST="$FILE_PATH:$JAR_LIST"
done

# Get the classpath
CLASSPATH=" -classpath \"$INSTALL_DIR:$JAR_LIST:\""

# Get the main class
MAIN_CLASS=" com.ibm.xtools.comparemerge.typemanager.internal.TypeManagerOperation"

# Must set up libary path for os to find the swt static libraries
SWT_DIR="$ECLIPSE_DIR/configuration/org.eclipse.osgi/bundles"
if [ ! -d $SWT_DIR ]; then
	SWT_DIR="$HOME/.eclipse/"
fi
#echo "SWT_DIR=$SWT_DIR"
SO_FILE_LIST=`find "$SWT_DIR" -name libswt-*.so`
SWT_SO_DIR=""
PREV_SO_DIR=""
for SO_FILE_PATH in $SO_FILE_LIST; do
	SO_DIR="$(dirname $SO_FILE_PATH)"
#	echo "SO_FILE_PATH=$SO_FILE_PATH"
	if [ ! "$PREV_SO_DIR" == "$SO_DIR" ]; then
#		echo "Add $SO_DIR"
		SWT_SO_DIR="$SO_DIR:$SWT_SO_DIR"
		PREV_SO_DIR="$SO_DIR"
	fi
#	SWT_SO_DIR="$(dirname $SO_FILE_PATH)"
#	break
done
LD_LIBRARY_PATH="$ECLIPSE_DIR:$INSTALL_DIR:$LD_LIBRARY_PATH:$SWT_SO_DIR"
export LD_LIBRARY_PATH

# Get the vmargs for the jre
VMARGS=" -Djava.library.path=\"$LD_LIBRARY_PATH\""

# Get the command line arguments
COMMAND_LINE_ARGS="$(basename $0) "

old_IFS=$IFS
IFS='\'
for param in $*; do
    COMMAND_LINE_ARGS="$COMMAND_LINE_ARGS \"$param\""
done
IFS=$old_IFS

# get the current working directory
CWD="-cwd \"$PWD\""

# Compose the full command
COMMAND="$JAVA_RUNTIME $VMARGS $CLASSPATH $MAIN_CLASS $COMMAND_LINE_ARGS $CWD"

# echo "Launch Command=$COMMAND"

# Execute the command
eval $COMMAND

# Get the exit code of the command
status="$?"

# Exit the script with the exit code
exit $status
